var f = Object.freeze({
  Linear: Object.freeze({
    None: function(u) {
      return u;
    },
    In: function(u) {
      return u;
    },
    Out: function(u) {
      return u;
    },
    InOut: function(u) {
      return u;
    }
  }),
  Quadratic: Object.freeze({
    In: function(u) {
      return u * u;
    },
    Out: function(u) {
      return u * (2 - u);
    },
    InOut: function(u) {
      return (u *= 2) < 1 ? 0.5 * u * u : -0.5 * (--u * (u - 2) - 1);
    }
  }),
  Cubic: Object.freeze({
    In: function(u) {
      return u * u * u;
    },
    Out: function(u) {
      return --u * u * u + 1;
    },
    InOut: function(u) {
      return (u *= 2) < 1 ? 0.5 * u * u * u : 0.5 * ((u -= 2) * u * u + 2);
    }
  }),
  Quartic: Object.freeze({
    In: function(u) {
      return u * u * u * u;
    },
    Out: function(u) {
      return 1 - --u * u * u * u;
    },
    InOut: function(u) {
      return (u *= 2) < 1 ? 0.5 * u * u * u * u : -0.5 * ((u -= 2) * u * u * u - 2);
    }
  }),
  Quintic: Object.freeze({
    In: function(u) {
      return u * u * u * u * u;
    },
    Out: function(u) {
      return --u * u * u * u * u + 1;
    },
    InOut: function(u) {
      return (u *= 2) < 1 ? 0.5 * u * u * u * u * u : 0.5 * ((u -= 2) * u * u * u * u + 2);
    }
  }),
  Sinusoidal: Object.freeze({
    In: function(u) {
      return 1 - Math.sin((1 - u) * Math.PI / 2);
    },
    Out: function(u) {
      return Math.sin(u * Math.PI / 2);
    },
    InOut: function(u) {
      return 0.5 * (1 - Math.sin(Math.PI * (0.5 - u)));
    }
  }),
  Exponential: Object.freeze({
    In: function(u) {
      return u === 0 ? 0 : Math.pow(1024, u - 1);
    },
    Out: function(u) {
      return u === 1 ? 1 : 1 - Math.pow(2, -10 * u);
    },
    InOut: function(u) {
      return u === 0 ? 0 : u === 1 ? 1 : (u *= 2) < 1 ? 0.5 * Math.pow(1024, u - 1) : 0.5 * (-Math.pow(2, -10 * (u - 1)) + 2);
    }
  }),
  Circular: Object.freeze({
    In: function(u) {
      return 1 - Math.sqrt(1 - u * u);
    },
    Out: function(u) {
      return Math.sqrt(1 - --u * u);
    },
    InOut: function(u) {
      return (u *= 2) < 1 ? -0.5 * (Math.sqrt(1 - u * u) - 1) : 0.5 * (Math.sqrt(1 - (u -= 2) * u) + 1);
    }
  }),
  Elastic: Object.freeze({
    In: function(u) {
      return u === 0 ? 0 : u === 1 ? 1 : -Math.pow(2, 10 * (u - 1)) * Math.sin((u - 1.1) * 5 * Math.PI);
    },
    Out: function(u) {
      return u === 0 ? 0 : u === 1 ? 1 : Math.pow(2, -10 * u) * Math.sin((u - 0.1) * 5 * Math.PI) + 1;
    },
    InOut: function(u) {
      return u === 0 ? 0 : u === 1 ? 1 : (u *= 2, u < 1 ? -0.5 * Math.pow(2, 10 * (u - 1)) * Math.sin((u - 1.1) * 5 * Math.PI) : 0.5 * Math.pow(2, -10 * (u - 1)) * Math.sin((u - 1.1) * 5 * Math.PI) + 1);
    }
  }),
  Back: Object.freeze({
    In: function(u) {
      var t = 1.70158;
      return u === 1 ? 1 : u * u * ((t + 1) * u - t);
    },
    Out: function(u) {
      var t = 1.70158;
      return u === 0 ? 0 : --u * u * ((t + 1) * u + t) + 1;
    },
    InOut: function(u) {
      var t = 2.5949095;
      return (u *= 2) < 1 ? 0.5 * (u * u * ((t + 1) * u - t)) : 0.5 * ((u -= 2) * u * ((t + 1) * u + t) + 2);
    }
  }),
  Bounce: Object.freeze({
    In: function(u) {
      return 1 - f.Bounce.Out(1 - u);
    },
    Out: function(u) {
      return u < 0.36363636363636365 ? 7.5625 * u * u : u < 0.7272727272727273 ? 7.5625 * (u -= 0.5454545454545454) * u + 0.75 : u < 0.9090909090909091 ? 7.5625 * (u -= 0.8181818181818182) * u + 0.9375 : 7.5625 * (u -= 0.9545454545454546) * u + 0.984375;
    },
    InOut: function(u) {
      return u < 0.5 ? f.Bounce.In(u * 2) * 0.5 : f.Bounce.Out(u * 2 - 1) * 0.5 + 0.5;
    }
  }),
  generatePow: function(u) {
    return u === void 0 && (u = 4), u = u < Number.EPSILON ? Number.EPSILON : u, u = u > 1e4 ? 1e4 : u, {
      In: function(i) {
        return Math.pow(i, u);
      },
      Out: function(i) {
        return 1 - Math.pow(1 - i, u);
      },
      InOut: function(i) {
        return i < 0.5 ? Math.pow(i * 2, u) / 2 : (1 - Math.pow(2 - i * 2, u)) / 2 + 0.5;
      }
    };
  }
});
export {
  f as default
};
